package pl.nettigo.esp.configurator.adapter;

import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;

import java.net.InetAddress;
import java.util.LinkedList;
import java.util.List;

import pl.nettigo.esp.configurator.R;
import pl.nettigo.esp.configurator.model.EspDevice;

public class DevicesAdapter extends RecyclerView.Adapter<DevicesAdapter.ViewHolder> {
    private List<EspDevice> mDataset;
    private OnSetupButtonClickListener onSetupButtonClickListener = null;

    public static class ViewHolder extends RecyclerView.ViewHolder {
        public TextView mSerialNumber;
        public TextView mIpAddress;
        public Button mSetupButton;

        public ViewHolder(View itemView) {
            super(itemView);
            mSerialNumber = itemView.findViewById(R.id.device_sn);
            mIpAddress = itemView.findViewById(R.id.device_ip);
            mSetupButton = itemView.findViewById(R.id.device_setup);
        }
    }

    public DevicesAdapter(List<EspDevice> devices) {
        this.mDataset = new LinkedList<>(devices);
    }

    public DevicesAdapter() {
        this.mDataset = new LinkedList<>();
    }

    public void setOnSetupButtonClickListener(OnSetupButtonClickListener onSetupButtonClickListener) {
        this.onSetupButtonClickListener = onSetupButtonClickListener;
    }

    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.viewholder_device, parent, false);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(ViewHolder holder, int position) {
        final EspDevice device = mDataset.get(position);

        holder.mSerialNumber.setText(device.getSerialNumber());

        InetAddress ip = device.getIpAddress();
        if(ip != null) {
            holder.mIpAddress.setText(ip.toString().replace("/", ""));
        } else {
            holder.mIpAddress.setText(null);
        }
        holder.mSetupButton.setOnClickListener(new Button.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (onSetupButtonClickListener != null) {
                    onSetupButtonClickListener.onSetupButtonClick(device);
                }
            }
        });
    }

    @Override
    public int getItemCount() {
        return mDataset.size();
    }

    public void clearList() {
        mDataset.clear();
        notifyDataSetChanged();
    }

    public boolean addDevice(EspDevice device) {
        boolean result = mDataset.add(device);
        notifyItemInserted(mDataset.size() - 1);
        return result;
    }

    public void removeDevice(EspDevice device) {
        int position = mDataset.indexOf(device);
        mDataset.remove(position);
        notifyItemRemoved(position);
    }

    public interface OnSetupButtonClickListener {
        void onSetupButtonClick(EspDevice device);
    }
}
